@@ -197,6 +197,12 @@ class Conversation:
 
     def enter(self) -> None:
         """"""
+        async def try_in_task() -> None:
+            try:
+                await in_task()
+            except Exception as exc:
+                await self.context.bot.dispatcher.dispatch_exception(exc)
+
         async def in_task() -> None:
             """"""
             self.state = await self.handler.handle_enter(self.enter_message,
@@ -229,4 +235,4 @@ class Conversation:
                     raise ConversationError(
                         "Undefined conversation state " \
                         f"'{self.state}' returned by handler!")
-        self.background_task = asyncio.create_task(in_task())
+        self.background_task = asyncio.create_task(try_in_task())
